==> haskell-conduit-extra-1.3.8-69-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-extra
version:              1.3.8
visibility:           public
id:                   conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6
key:                  conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.

category:             Data, Conduit
abi:                  48c0c1a44f0c63d64ffba586d4db60e1
exposed:              True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib

import-dirs:          /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-extra
hs-libraries:         HSconduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6
depends:
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    directory-1.3.8.5 filepath-1.4.300.1
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi process-1.6.19.0
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs stm-2.5.1.0
    streaming-commons-0.2.3.1-J8SxFARI4BPDYt3Np6OVv5 text-2.0.2
    transformers-0.6.1.0 typed-process-0.2.13.0-6gQ7sh9yVXJ5lWoFriePEE
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock

haddock-html:         /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-extra-1.3.8-71-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-extra
version:              1.3.8
visibility:           public
id:                   conduit-extra-1.3.8-GHF5wYhQp30HUaLAtCbs0G
key:                  conduit-extra-1.3.8-GHF5wYhQp30HUaLAtCbs0G
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.

category:             Data, Conduit
abi:                  9e4ad4eb16a5da68b1dd3e57b3128713
exposed:              True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib

import-dirs:          /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-extra
hs-libraries:         HSconduit-extra-1.3.8-GHF5wYhQp30HUaLAtCbs0G
depends:
    async-2.2.5-BOONqED6PxbDsY8XxcvMc4
    attoparsec-0.14.4-8hLS1m777hPFjiaInp95BL base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy
    directory-1.3.8.5 filepath-1.4.300.1
    network-3.1.4.0-xB4epdb1XO3ZKzAxljM4X
    primitive-0.9.1.0-7ibydtGngalFw21zVTsTma process-1.6.19.0
    resourcet-1.2.6-JtO0n9rtgTt543EMYn7K77 stm-2.5.1.0
    streaming-commons-0.2.3.1-p6JZxPGlgm2ju1b9E77qr text-2.0.2
    transformers-0.6.1.0 typed-process-0.2.13.0-G2AJfTR0sk5D0GWHf20Rf3
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock

haddock-html:         /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
